Getting Started: Main Program
*****************************

make_hst_spec_previews
======================
.. automodule:: make_hst_spec_previews
    :members: 
    :private-members:
    :undoc-members:
    :noindex:

make_jwst_spec_previews
=======================
.. automodule:: make_jwst_spec_previews
    :members: 
    :private-members:
    :undoc-members:
    :noindex:
